@@ -3,13 +3,14 @@ import sys
 import unittest
 import warnings
 from cStringIO import StringIO
+from nose.result import _TextTestResult
 here = os.path.dirname(__file__)
 support = os.path.join(here, 'support')
 
 
 class TestRunner(unittest.TextTestRunner):
     def _makeResult(self):
-        self.result = unittest._TextTestResult(
+        self.result = _TextTestResult(
             self.stream, self.descriptions, self.verbosity)
         return self.result
     
