@@ -87,6 +87,7 @@ import sys
 import time
 import traceback
 import unittest
+import pickle
 import nose.case
 from nose.core import TextTestRunner
 from nose import failure
@@ -95,6 +96,11 @@ from nose.plugins.base import Plugin
 from nose.result import TextTestResult
 from nose.suite import ContextSuite
 from nose.util import test_address
+try:
+    # 2.7+
+    from unittest.runner import _WritelnDecorator
+except ImportError:
+    from unittest import _WritelnDecorator
 from Queue import Empty
 from warnings import warn
 try:
@@ -108,10 +114,6 @@ Process = Queue = Pool = Event = None
 
 def _import_mp():
     global Process, Queue, Pool, Event
-    if sys.platform == 'win32':
-        warn("multiprocess plugin is not available on windows",
-             RuntimeWarning)
-        return
     try:
         from multiprocessing import Process as Process_, \
             Queue as Queue_, Pool as Pool_, Event as Event_
@@ -120,7 +122,7 @@ def _import_mp():
         warn("multiprocessing module is not available, multiprocess plugin "
              "cannot be used", RuntimeWarning)
 
-        
+
 class TestLet:
     def __init__(self, case):
         try:
@@ -146,13 +148,11 @@ class MultiProcess(Plugin):
     """
     score = 1000
     status = {}
-    
+
     def options(self, parser, env):
         """
         Register command-line options.
         """
-        if sys.platform == 'win32':
-            return
         parser.add_option("--processes", action="store",
                           default=env.get('NOSE_PROCESSES', 0),
                           dest="multiprocess_workers",
@@ -172,8 +172,6 @@ class MultiProcess(Plugin):
         """
         Configure plugin.
         """
-        if sys.platform == 'win32':
-            return
         try:
             self.status.pop('active')
         except KeyError:
@@ -181,6 +179,9 @@ class MultiProcess(Plugin):
         if not hasattr(options, 'multiprocess_workers'):
             self.enabled = False
             return
+        # don't start inside of a worker process
+        if config.worker:
+            return
         self.config = config
         try:
             workers = int(options.multiprocess_workers)
@@ -195,7 +196,7 @@ class MultiProcess(Plugin):
             self.config.multiprocess_workers = workers
             self.config.multiprocess_timeout = int(options.multiprocess_timeout)
             self.status['active'] = True
-            
+
     def prepareTestLoader(self, loader):
         """Remember loader class so MultiProcessTestRunner can instantiate
         the right loader.
@@ -290,7 +291,7 @@ class MultiProcessTestRunner(TextTestRunner):
                                              shouldStop,
                                              self.loaderClass,
                                              result.__class__,
-                                             self.config))
+                                             pickle.dumps(self.config)))
             # p.setDaemon(True)
             p.start()
             workers.append(p)
@@ -365,6 +366,11 @@ class MultiProcessTestRunner(TextTestRunner):
             else:
                 parts.append(mod)
         else:
+            # strip __init__.py(c) from end of file part
+            # if present, having it there confuses loader
+            dirname, basename = os.path.split(file)
+            if basename.startswith('__init__'):
+                file = dirname
             parts.append(file)
         if call is not None:
             parts.append(call)
@@ -382,7 +388,7 @@ class MultiProcessTestRunner(TextTestRunner):
             or not getattr(test, 'can_split', True)
             or not isinstance(test, unittest.TestSuite)):
             # regular test case, or a suite with context fixtures
-            
+
             # special case: when run like nosetests path/to/module.py
             # the top-level suite has only one item, and it shares
             # the same context as that item. In that case, we want the
@@ -447,16 +453,19 @@ class MultiProcessTestRunner(TextTestRunner):
 
 def runner(ix, testQueue, resultQueue, shouldStop,
            loaderClass, resultClass, config):
+    config = pickle.loads(config)
+    config.plugins.begin()
     log.debug("Worker %s executing", ix)
+    log.debug("Active plugins worker %s: %s", ix, config.plugins._plugins)
     loader = loaderClass(config=config)
     loader.suiteClass.suiteClass = NoSharedFixtureContextSuite
-
+    
     def get():
         case = testQueue.get(timeout=config.multiprocess_timeout)
         return case
 
     def makeResult():
-        stream = unittest._WritelnDecorator(StringIO())
+        stream = _WritelnDecorator(StringIO())
         result = resultClass(stream, descriptions=1,
                              verbosity=config.verbosity,
                              config=config)
